@@ -20,3 +20,7 @@ from .triplet_loss import TripletLoss  # noqa
 from .metric_loss import MetricLoss  # noqa
 from .circle_loss import CircleLoss  # noqa
 from .multisim_loss import MultiSimilarityLoss  # noqa
+from .simsiam import SimSiamLoss  # noqa
+from .simclr import SimCLRLoss  # noqa
+from .barlow import Barlow  # noqa
+from .softnn_loss import SoftNearestNeighborLoss  # noqa
